# yifei_tech_support 🐈


## 打开电脑终端
* Mac:
	* 进入启动台，在搜索栏搜索`终端`，单击打开
* Win:
	* 同时按下键盘上的`Win` 和 `R`，在运行对话框中输入`cmd`，点击确定

## 第一次安装使用
1. </a>打开终端
2. </a>安装所需环境
	a. </a>在终端中输入 `pip3 install playwright==1.23.0` 回车，等待安装结束
	b. </a>继续输入 `playwright install` 回车，等待安装结束

3. </a>安装播放量包裹
	a. </a>在终端中输入`git clone --recursive https://github.com/yifei-techsupport/yifei-tech-support.git` 回车，等待结束
	b. </a>继续输入 `python3 -m pip install yifei_tech_support` 回车，等待结束

## 更新包裹
1. </a>打开终端
2. </a>更新播放量包裹
	a. </a>在终端中输入`git clone --recursive https://github.com/yifei-techsupport/yifei-tech-support.git` 回车，等待结束
	b. </a>继续输入 `python3 -m pip install yifei_tech_support` 回车，等待结束